@@ -8,8 +8,13 @@ import socket
 import sys
 import time
 
+# To prevent a race condition with ZMQ
+# See issue 5324
+if not sys.platform == 'darwin':
+    import zmq
+
 # This import is needed to fix errors with OpenGL when installed using pip
-# See issue #3332
+# See issue 3332
 try:
     from OpenGL import GL
 except ImportError:
@@ -72,8 +77,13 @@ def main():
     #==========================================================================
     if CONF.get('main', 'high_dpi_custom_scale_factor'):
         factors = str(CONF.get('main', 'high_dpi_custom_scale_factors'))
-        os.environ['QT_SCREEN_SCALE_FACTORS'] = factors
+        f = list(filter(None, factors.split(';')))
+        if len(f) == 1:
+            os.environ['QT_SCALE_FACTOR'] = f[0]
+        else:
+            os.environ['QT_SCREEN_SCALE_FACTORS'] = factors
     else:
+        os.environ['QT_SCALE_FACTOR'] = ''
         os.environ['QT_SCREEN_SCALE_FACTORS'] = ''
 
     # Prevent Spyder from crashing in macOS if locale is not defined
